/* defaultForms.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "defaultForms.h"
#include "database.h"

DefaultForms::FormIDs DefaultForms::_form_ids;
bool DefaultForms::_got_forms = false;

// check_default will not change the form_id if it already refers to a
// real form, but if it does not, it will change it to point to the
// default form for the indicated table.
void DefaultForms::
check_default(int &form_id, TableID table_id) {
  if (form_id < 0) {
    form_id = get_form_id(table_id);
  }
}

int DefaultForms::
get_form_id(TableID table_id) {
  if (!_got_forms) {
    get_forms();
  }

  FormIDs::const_iterator fi = _form_ids.find(table_id);
  if (fi == _form_ids.end()) {
    return -1;
  } else {
    return (*fi).second;
  }
}

void DefaultForms::
get_forms() {
  QueryResult qr = music_db->sql_command
    ("SELECT table_id, form_id FROM default_forms");

  int num_rows = qr.get_num_rows();
  for (int i = 0; i < num_rows; i++) {
    TableID table_id = (TableID)qr.get_cell(i, 0).get_int();
    int form_id = qr.get_cell(i, 1).get_int();
    _form_ids[table_id] = form_id;
  }

  _got_forms = true;
}


