/* playlistControls.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef PLAYLISTCONTROLS_H
#define PLAYLISTCONTROLS_H

#include "dataset.h"
#include "songPlayerControls.h"
#include "playlistProxy.h"
#include "palomaDialog.h"

#include <gtk--.h>

class TableDataProxy;
class SongDialog;
class CDReader;

// This class encapsulates a SongPlayerControls widget that is
// attached to a CList of song ID's.  When the user clicks on a
// particular song, the controls will prepare to play that song; if
// the user lets the controls reach the end of one song, it will go on
// to play the next.

class PlaylistControls : public Gtk_HBox {
public:
  PlaylistControls(const Dataset &data);
  ~PlaylistControls();

  void layout(const PlaylistProxy &playlist);

  // Call clear_player() to disassociate from the cd_reader, to allow
  // the cd_reader to be safely deleted.
  void clear_player();

  int get_current_row() const;

  void stop();
  void play();

  Signal0 ended;

private:
  void got_select_row(gint row, gint column, GdkEvent *event);
  void song_player_stopped_at_end();
  void next_button_clicked();
  void prev_button_clicked();

  void make_pixmaps();

  Gtk_HBox _cbox;
  SongPlayerControls _player_controls;
  Gtk_Button _next_button;
  Gtk_Button _prev_button;
  Gtk_Pixmap _next_pixmap;
  Gtk_Pixmap _prev_pixmap;

  static Gdk_Pixmap _next_gdk_pixmap;
  static Gdk_Bitmap _next_gdk_mask;
  static Gdk_Pixmap _prev_gdk_pixmap;
  static Gdk_Bitmap _prev_gdk_mask;
  static bool _got_pixmaps;

  Dataset _data;

  PlaylistProxy _playlist;
  Gtk_CList *_clist;
  CDReader *_cd_reader;
};

#endif
