/* tableInfo.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef TABLEINFO_H
#define TABLEINFO_H

#include <string>
#include <iostream.h>

class Database;

extern Database *music_db;

class TableDef;

enum TableID {
  TI_no_table,  // This is just used to flag the absence of data.
  TI_songs,
  TI_songs_extension,
  TI_cds,
  TI_cds_extension,
  TI_artists,
  TI_artists_extension,
  TI_configure,
  TI_volumes,
  TI_soundfile,
  TI_combo_items,
  num_table_ids   // This constant marks the number of TableID values.
};

ostream &operator << (ostream &out, TableID table_id);

enum SongFieldID {
  SFI_performer,
  SFI_writer,
  SFI_length,
  SFI_loaded_time,
  SFI_file_type,
  SFI_volume_id,
  SFI_name,
  SFI_filename,
};

enum CDFieldID {
  CFI_cddb,
  CFI_performer,
  CFI_writer,
  CFI_title,
};

enum ArtistFieldID {
  AFI_last_name,
  AFI_first_name,
  AFI_name_suffix,
  AFI_group_prefix,
  AFI_group_name,
};

enum ConfigureFieldID {
  CFI_database_version,
  CFI_cdrom_type,
  CFI_cdrom_load_type,
  CFI_cdrom_want_type,
  CFI_cdrom_load_volume,
  CFI_cdrom_want_volume,
};

enum VolumesFieldID {
  VFI_bucket_size,
  VFI_current_bucket,
  VFI_description,
  VFI_definition,
  VFI_bucket_name,
};

enum SoundfileFieldID {
  SFFI_sajber_backend,
  SFFI_description,
  SFFI_play_command,
  SFFI_play_response,
  SFFI_verify_command,
  SFFI_verify_response,
};

enum ComboItemsFieldID {
  CIFI_label,
};

Database *get_table_db(TableID table_id);
string get_table_name(TableID table_id);
string get_table_key(TableID table_id);
string get_table_key_sequence(TableID table_id);
bool is_extension_table(TableID table_id);

TableDef *get_system_table(TableID table_id);
void define_all_tables();

#endif
